#[non_exhaustive]pub struct ChannelChatMessageV1Payload {Show 21 fields
pub broadcaster_user_id: UserId,
pub broadcaster_user_name: DisplayName,
pub broadcaster_user_login: UserName,
pub chatter_user_id: UserId,
pub chatter_user_name: DisplayName,
pub chatter_user_login: UserName,
pub message_id: MsgId,
pub message: Message,
pub message_type: MessageType,
pub badges: Vec<Badge>,
pub cheer: Option<Cheer>,
pub color: HexColor,
pub reply: Option<Reply>,
pub channel_points_custom_reward_id: Option<RewardId>,
pub channel_points_animation_id: Option<String>,
pub source_broadcaster_user_id: Option<UserId>,
pub source_broadcaster_user_name: Option<DisplayName>,
pub source_broadcaster_user_login: Option<UserName>,
pub source_message_id: Option<MsgId>,
pub source_badges: Vec<Badge>,
pub is_source_only: Option<bool>,
}eventsub only.Expand description
channel.chat.message response payload.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.broadcaster_user_id: UserIdThe broadcaster user ID.
broadcaster_user_name: DisplayNameThe broadcaster display name.
broadcaster_user_login: UserNameThe broadcaster login.
chatter_user_id: UserIdThe user ID of the user that sent the message.
chatter_user_name: DisplayNameThe user name of the user that sent the message.
chatter_user_login: UserNameThe user login of the user that sent the message.
message_id: MsgIdA UUID that identifies the message.
message: MessageThe structured chat message.
message_type: MessageTypeThe type of message.
badges: Vec<Badge>List of chat badges.
cheer: Option<Cheer>Metadata if this message is a cheer.
color: HexColorThe color of the user’s name in the chat room.
This is a hexadecimal RGB color code in the form, #<RGB>.
This may be empty if it is never set.
reply: Option<Reply>Metadata if this message is a reply.
channel_points_custom_reward_id: Option<RewardId>The ID of a channel points custom reward that was redeemed.
channel_points_animation_id: Option<String>An ID for the type of animation selected as part of an “animate my message” redemption.
source_broadcaster_user_id: Option<UserId>Only present when in a shared chat session. The broadcaster user ID of the channel the message was sent from.
source_broadcaster_user_name: Option<DisplayName>Only present when in a shared chat session. The user name of the broadcaster of the channel the message was sent from.
source_broadcaster_user_login: Option<UserName>Only present when in a shared chat session. The login of the broadcaster of the channel the message was sent from.
source_message_id: Option<MsgId>Only present when in a shared chat session. The UUID that identifies the source message from the channel the message was sent from.
source_badges: Vec<Badge>Only present when in a shared chat session. The list of chat badges for the chatter in the channel the message was sent from.
is_source_only: Option<bool>Determines if a message delivered during a shared chat session is only sent to the source channel.